=== modified file 'drizzled/item/param.cc'
--- drizzled/item/param.cc	2009-01-28 02:09:24 +0000
+++ drizzled/item/param.cc	2009-02-04 01:51:06 +0000
@@ -26,6 +26,7 @@
 #include <drizzled/item/param.h>
 #include CMATH_H
 #include <drizzled/sql_string.h>
+#include <mystrings/utf8.h>
 
 Item *Item_param::safe_charset_converter(const CHARSET_INFO * const tocs)
 {
@@ -536,19 +537,6 @@
 }
 
 
-/* Borrowed from libicu header */
-
-#define U8_IS_SINGLE(c) (((c)&0x80)==0)
-#define U8_LENGTH(c) \
-    ((uint32_t)(c)<=0x7f ? 1 : \
-        ((uint32_t)(c)<=0x7ff ? 2 : \
-            ((uint32_t)(c)<=0xd7ff ? 3 : \
-                ((uint32_t)(c)<=0xdfff || (uint32_t)(c)>0x10ffff ? 0 : \
-                    ((uint32_t)(c)<=0xffff ? 3 : 4)\
-                ) \
-            ) \
-        ) \
-    )
 
 /*
   Add escape characters to a string (blob?) to make it suitable for a insert

=== modified file 'libdrizzleclient/libdrizzle.c'
--- libdrizzleclient/libdrizzle.c	2009-02-02 20:06:06 +0000
+++ libdrizzleclient/libdrizzle.c	2009-02-04 01:51:06 +0000
@@ -54,20 +54,7 @@
 
 #include <stdlib.h>
 #include <string.h>
-
-/* Borrowed from libicu header */
-
-#define U8_IS_SINGLE(c) (((c)&0x80)==0)
-#define U8_LENGTH(c) \
-    ((uint32_t)(c)<=0x7f ? 1 : \
-        ((uint32_t)(c)<=0x7ff ? 2 : \
-            ((uint32_t)(c)<=0xd7ff ? 3 : \
-                ((uint32_t)(c)<=0xdfff || (uint32_t)(c)>0x10ffff ? 0 : \
-                    ((uint32_t)(c)<=0xffff ? 3 : 4)\
-                ) \
-            ) \
-        ) \
-    )
+#include <mystrings/utf8.h>
 
 
 #undef net_buffer_length

=== modified file 'mystrings/Makefile.am'
--- mystrings/Makefile.am	2009-01-19 06:47:53 +0000
+++ mystrings/Makefile.am	2009-02-04 01:51:06 +0000
@@ -19,7 +19,8 @@
 mystringsincludedir = ${includedir}/mystrings
 dist_mystringsinclude_HEADERS = 	decimal.h \
 					m_ctype.h \
-					m_string.h
+					m_string.h \
+				utf8.h
 
 noinst_HEADERS =	my_uctype.h \
 			t_ctype.h

=== added file 'mystrings/utf8.h'
--- mystrings/utf8.h	1970-01-01 00:00:00 +0000
+++ mystrings/utf8.h	2009-02-04 01:51:06 +0000
@@ -0,0 +1,85 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+   vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+
+Copyright (c) 1995-2006 International Business Machines Corporation and others
+
+All rights reserved.
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"),
+to deal in the Software without restriction, including without limitation
+the rights to use, copy, modify, merge, publish, distribute, and/or sell
+copies of the Software, and to permit persons
+to whom the Software is furnished to do so, provided that the above
+copyright notice(s) and this permission notice appear in all copies
+of the Software and that both the above copyright notice(s) and this
+permission notice appear in supporting documentation.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLI
+ED, 
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT OF THIRD PARTY RIGHTS. IN NO EVENT SHALL
+THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM,
+OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER
+RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
+NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
+USE OR PERFORMANCE OF THIS SOFTWARE.
+
+Except as contained in this notice, the name of a copyright holder shall not be
+used in advertising or otherwise to promote the sale, use or other dealings in
+this Software without prior written authorization of the copyright holder.
+*/
+
+#ifndef MYSTRINGS_UTF8_H
+#define MYSTRINGS_UTF8_H
+
+/**
+ * Does this code unit (byte) encode a code point by itself (US-ASCII 0..0x7f)?
+ * @param c 8-bit code unit (byte)
+ * @return TRUE or FALSE
+ * @stable ICU 2.4
+ */
+#define U8_IS_SINGLE(c) (((c)&0x80)==0)
+
+/**
+ * Is this code unit (byte) a UTF-8 lead byte?
+ * @param c 8-bit code unit (byte)
+ * @return TRUE or FALSE
+ * @stable ICU 2.4
+ */
+#define U8_IS_LEAD(c) ((uint8_t)((c)-0xc0)<0x3e)
+
+/**
+ * Is this code unit (byte) a UTF-8 trail byte?
+ * @param c 8-bit code unit (byte)
+ * @return TRUE or FALSE
+ * @stable ICU 2.4
+ */
+#define U8_IS_TRAIL(c) (((c)&0xc0)==0x80)
+
+/**
+ * How many code units (bytes) are used for the UTF-8 encoding
+ * of this Unicode code point?
+ * @param c 32-bit code point
+ * @return 1..4, or 0 if c is a surrogate or not a Unicode code point
+ * @stable ICU 2.4
+ */
+#define U8_LENGTH(c) \
+    ((uint32_t)(c)<=0x7f ? 1 : \
+        ((uint32_t)(c)<=0x7ff ? 2 : \
+            ((uint32_t)(c)<=0xd7ff ? 3 : \
+                ((uint32_t)(c)<=0xdfff || (uint32_t)(c)>0x10ffff ? 0 : \
+                    ((uint32_t)(c)<=0xffff ? 3 : 4)\
+                ) \
+            ) \
+        ) \
+    )
+
+/**
+ * The maximum number of UTF-8 code units (bytes) per Unicode code point (U+0000..U+10ffff).
+ * @return 4
+ * @stable ICU 2.4
+ */
+#define U8_MAX_LENGTH 4
+
+#endif /* MYSTRINGS_UTF8_H */

